=========
Tutorials
=========

This part of the documentation guides you through all of the library's
usage patterns.

Automatic generation from .ipynb files requires:

- pandoc

And documentation development in .org files requires:

- emacs with org babel
- jupyter (and kernel e.g. cloph-310)
- r

.. toctree::
   :numbered:

   usage
   usage2
   prtecan
